@@ -13,6 +13,11 @@ from urllib import urlencode
 import gdata.youtube
 import gdata.youtube.service
 
+if os.geteuid() == 0:
+  print "Don't run this as root, please..."
+  sys.exit(1)
+
+
 STATE_FILE = "/tmp/ytcli_state"
 FEED_FILE  = "/tmp/ytcli_feed"
 DL_LOG = "/tmp/ytcli_log"
